@@ -6,38 +6,54 @@ use warnings;
 use Carp;
 
 #require Exporter;
-use Mail::Miner::DBI;
-use Mail::Miner::Attachment;
-use Mail::Miner::Asset;
-use Mail::Miner::Mail;
+use Mail::Miner::Assets;
+
+eval {
+require Mail::Miner::DBI;
+require Mail::Miner::Attachment;
+require Mail::Miner::Asset;
+require Mail::Miner::Mail;
+};
 
 use MIME::Parser;
 
 #our @EXPORT_OK = ( );
 #our @EXPORT = qw( );
-our $VERSION = '2.0';
+our $VERSION = '2.6_01';
+our %recognisers;
 
 # Find all Mail::Miner::Recogniser modules
 use File::Spec::Functions qw(:DEFAULT splitdir);
 
-my @files = map { glob(catfile($_,"*.pm")) }
-           grep { -d $_ }
-            map { catdir($_, "Mail", "Miner", "Recogniser") }
-            exists $INC{"blib.pm"} ? grep {/blib/} @INC : @INC;
+sub import { 
+    my ($class, %args) = @_;
+    my @additional_modules = ($args{recognisers});
+    @additional_modules = @{$additional_modules[0]} 
+        if ref $additional_modules[0] eq "ARRAY";
+   s/::/\//g for @additional_modules;
+    local $_=$_; # Breaking $_ considered evil
 
-require $_ for @files; # No need for import.
+my @files = grep length, map { glob(catfile($_,"*.pm"))  }
+            grep { -d $_ }
+            map { my $path = $_;
+                  catdir($path, "Mail", "Miner", "Recogniser"),
+                  map { catdir($path, $_) } @additional_modules
+            }
+            exists $INC{"blib.pm"} ? grep {/blib/} @INC :
+            @INC;
+my %seen;
+@files = grep {!$seen{$_}++} @files;
 
-no warnings 'once';
 
-our @modules = map {
-    s/.pm$//;
-    s{.*(?=Mail/Miner)}{};
-    join "::", splitdir($_)
-} @files;
+my @dummy = @files;
+for my $x (@dummy) {
+    require $x; # No need for import.
+}
 
-our %plugins = map { $Mail::Miner::recognisers{$_}{keyword} => $_ } 
-             keys %Mail::Miner::recognisers;
+}
+sub modules { sort keys %recognisers };
 
+sub plugins { map { $recognisers{$_}{keyword} => $_ } modules() };
 our $parser = new MIME::Parser;
 $parser->output_to_core(1);
 # Preloaded methods go here.
@@ -102,7 +118,7 @@ convenient to.
 Everything else that C<Mail::Miner> finds out about a mail is an
 B<asset>. For instance, a very trivial asset is the date it was sent. A
 more complex asset could be the fact that it looks like it contains a
-phone number, and what the phone number is. 
+phone number, and what the phone number is.
 
 =head2 Recognisers
 
